//******************************************************************************
///
/// @file parser/_optionnames.h
///
/// This header file contains static character string arrays used primarily to
/// drive documentation associated with the yuqk fork of POV-Ray. The arrays are
/// used in the final executable to provide for scene description language (SDL)
/// functions word_is() and word_get(). The active function names array is used
/// with the 'no lower case, user identifier' checking if the executable is
/// compiled with that option (NO_LC_USER_IDENTIFIERS).
///
/// The arrays are maintained in several files in total:
///     _directivewords.h, _fakebyfnctwords.h, _fnnames.h, _keywords.h,
///     _oddwords.h and _optionnames.h.
///
/// @copyright
/// @parblock
///
/// Persistence of Vision Ray Tracer ('POV-Ray') version 3.8.
/// Copyright 1991-2024 Persistence of Vision Raytracer Pty. Ltd.
///
/// POV-Ray is free software: you can redistribute it and/or modify
/// it under the terms of the GNU Affero General Public License as
/// published by the Free Software Foundation, either version 3 of the
/// License, or (at your option) any later version.
///
/// POV-Ray is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU Affero General Public License for more details.
///
/// You should have received a copy of the GNU Affero General Public License
/// along with this program.  If not, see <http://www.gnu.org/licenses/>.
///
/// ----------------------------------------------------------------------------
///
/// POV-Ray is based on the popular DKB raytracer version 2.12.
/// DKBTrace was originally written by David K. Buck.
/// DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
///
/// @endparblock
///
//------------------------------------------------------------------------------
// SPDX-License-Identifier: AGPL-3.0-or-later
//******************************************************************************

#ifndef POVRAY_PARSER__OPTIONNAMES_H
#define POVRAY_PARSER__OPTIONNAMES_H

static char iOptionNames[][26] { "+a", "+ac", "+ag", "+am", "+b", "+bm", "+bs", "+c", "+cc", "+d", "+ec", "+ef", "+ef0",
    "+ep", "+er", "+f", "+ga", "+gd", "+gf", "+gi", "+gp", "+gr", "+gs", "+gw", "+h", "+hi", "+hr", "+i", "+j", "+k",
    "+kc", "+kf", "+kff", "+kfi", "+ki", "+kla", "+l", "+mb", "+mi", "+mv", "+o", "+p", "+q", "+r", "+rf", "+rfi",
    "+rfo", "+rm", "+rp", "+rs", "+rtc", "+rtr", "+rvp", "+sc", "+sf", "+sf0", "+sp", "+sr", "+ss", "+stp", "+su",
    "+th", "+ua", "+ur", "+v", "+w", "+wl", "+wt", "all_console", "all_file", "antialias", "antialias_confidence",
    "antialias_depth", "antialias_gamma", "antialias_min_depth", "antialias_threshold", "append_file", "bits_per_color",
    "bits_per_colour", "bounding", "bounding_method", "bounding_threshold", "bsp_baseaccesscost", "bsp_childaccesscost",
    "bsp_isectcost", "bsp_maxdepth", "bsp_misschance", "clock", "clockless_animation", "compression", "continue_trace",
    "create_continue_trace_log", "create_ini", "cyclic_animation", "debug_console", "debug_file", "declare", "display",
    "display_gamma", "dither", "dither_method", "end_column", "end_row", "fatal_console", "fatal_error_command",
    "fatal_error_return", "fatal_file", "file_gamma", "final_clock", "final_frame", "frame_step", "grayscale_output",
    "greyscale_output", "height", "high_reproducibility", "include_header", "include_ini", "initial_clock",
    "initial_frame", "input_file_name", "jitter", "jitter_amount", "library_path", "max_image_buffer_memory",
    "output_alpha", "output_file_name", "output_file_type", "output_to_file", "pause_when_done", "post_frame_command",
    "post_frame_return", "post_scene_command", "post_scene_return", "pre_frame_command", "pre_frame_return",
    "pre_scene_command", "pre_scene_return", "preview_end_size", "preview_start_size", "quality", "radiosity_file_name",
    "radiosity_from_file", "radiosity_to_file", "radiosity_vain_pretrace", "real_time_capture", "real_time_raytracing",
    "remove_bounds", "render_block_size", "render_block_step", "render_console", "render_file", "render_pattern",
    "sampling_method", "split_unions", "start_column", "start_row", "statistic_console", "statistic_file",
    "stochastic_seed", "subset_end_frame", "subset_start_frame", "user_abort_command", "user_abort_return", "verbose",
    "version", "warning_console", "warning_file", "warning_level", "width", "work_threads" };

static char oOptionNames[][26] { "+a0", "+hn", "+hs", "+ht", "+qr", "+ud", "+uf", "+ul", "+uo", "+uv", "+x",
    "buffer_output", "buffer_size", "create_histogram", "draw_vistas", "field_render", "histogram_grid_size",
    "histogram_name", "histogram_type", "light_buffer", "odd_field", "palette", "radiosity", "test_abort",
    "test_abort_count", "video_mode", "vista_buffer" };

static char nOptionNames[][26] { "+rm", "+rtc", "antialias_min_depth", "real_time_capture" };

#endif // POVRAY_PARSER__OPTIONNAMES_H
